@@ -36,6 +36,7 @@ SOFTWARE.
 #include <unistd.h>
 #include <string.h>
 #include "event_gpio.h"
+#include "common.h"
 
 const char *stredge[4] = {"none", "rising", "falling", "both"};
 
@@ -75,7 +76,7 @@ int epfd = -1;
 int gpio_export(unsigned int gpio)
 {
     int fd, len;
-    char str_gpio[3];
+    char str_gpio[10];
     struct gpio_exp *new_gpio, *g;
 
     if ((fd = open("/sys/class/gpio/export", O_WRONLY)) < 0)
@@ -169,7 +170,7 @@ int add_fd_list(unsigned int gpio, int fd)
 int open_value_file(unsigned int gpio)
 {
     int fd;
-    char filename[30];
+    char filename[40];
 
     // create file descriptor of value file
     snprintf(filename, sizeof(filename), "/sys/class/gpio/gpio%d/value", gpio);
@@ -182,7 +183,7 @@ int open_value_file(unsigned int gpio)
 int gpio_unexport(unsigned int gpio)
 {
     int fd, len;
-    char str_gpio[3];
+    char str_gpio[10];
     struct gpio_exp *g, *temp, *prev_g = NULL;
 
     close_value_fd(gpio);
@@ -218,17 +219,20 @@ int gpio_unexport(unsigned int gpio)
 int gpio_set_direction(unsigned int gpio, unsigned int in_flag)
 {
         int fd;
-        char filename[34];
+        char filename[40];
+        char direction[10] = { 0 };
 
         snprintf(filename, sizeof(filename), "/sys/class/gpio/gpio%d/direction", gpio);
         if ((fd = open(filename, O_WRONLY)) < 0)
             return -1;
 
-        if (in_flag)
-            write(fd, "out", 3);
-        else
-            write(fd, "in", 4);
+        if (in_flag) {
+            strncpy(direction, "out", ARRAY_SIZE(direction) - 1);
+        } else {
+            strncpy(direction, "in", ARRAY_SIZE(direction) - 1);
+        }
 
+        write(fd, direction, strlen(direction));
         close(fd);
         return 0;
 }
@@ -236,15 +240,15 @@ int gpio_set_direction(unsigned int gpio, unsigned int in_flag)
 int gpio_get_direction(unsigned int gpio, unsigned int *value)
 {
     int fd;
-    char direction[4];
-    char filename[34];
+    char direction[4] = { 0 };
+    char filename[40];
 
     snprintf(filename, sizeof(filename), "/sys/class/gpio/gpio%d/direction", gpio);
     if ((fd = open(filename, O_RDONLY | O_NONBLOCK)) < 0)
         return -1;
 
     lseek(fd, 0, SEEK_SET);
-    read(fd, &direction, 3);
+    read(fd, &direction, sizeof(direction) - 1);
 
     if (strcmp(direction, "out") == 0) {
         *value = OUTPUT;
@@ -258,18 +262,21 @@ int gpio_get_direction(unsigned int gpio, unsigned int *value)
 int gpio_set_value(unsigned int gpio, unsigned int value)
 {
     int fd;
-    char filename[30];
+    char filename[40];
+    char vstr[10];
 
     snprintf(filename, sizeof(filename), "/sys/class/gpio/gpio%d/value", gpio);
 
     if ((fd = open(filename, O_WRONLY)) < 0)
         return -1;
 
-    if (value)
-        write(fd, "1", 2);
-    else
-        write(fd, "0", 2);
+    if (value) {
+        strncpy(vstr, "1", ARRAY_SIZE(vstr) - 1);
+    } else {
+        strncpy(vstr, "0", ARRAY_SIZE(vstr) - 1);
+    }
 
+    write(fd, vstr, strlen(vstr));
     close(fd);
     return 0;
 }
@@ -286,7 +293,7 @@ int gpio_get_value(unsigned int gpio, unsigned int *value)
     }    
 
     lseek(fd, 0, SEEK_SET);
-    read(fd, &ch, 1);
+    read(fd, &ch, sizeof(ch));
 
     if (ch != '0') {
         *value = 1;
@@ -300,7 +307,7 @@ int gpio_get_value(unsigned int gpio, unsigned int *value)
 int gpio_set_edge(unsigned int gpio, unsigned int edge)
 {
         int fd;
-        char filename[29];
+        char filename[40];
 
         snprintf(filename, sizeof(filename), "/sys/class/gpio/gpio%d/edge", gpio);
 
@@ -626,7 +633,7 @@ int blocking_wait_for_edge(unsigned int gpio, unsigned int edge)
     if (n > 0)
     {
         lseek(events.data.fd, 0, SEEK_SET);
-        if (read(events.data.fd, &buf, 1) != 1)
+        if (read(events.data.fd, &buf, sizeof(buf)) != 1)
         {
             gpio_event_remove(gpio);
             return 6;
