@@ -21,6 +21,10 @@ class TestGPIOOutput:
         assert not int(value)
         GPIO.cleanup()
 
+    def test_direction_readback(self):
+        GPIO.setup("P8_10", GPIO.OUT)
+        direction = GPIO.gpio_function("P8_10")
+        assert direction == GPIO.OUT
     def test_output_greater_than_one(self):
         GPIO.setup("P8_10", GPIO.OUT)
         GPIO.output("P8_10", 2)
@@ -37,4 +41,4 @@ class TestGPIOOutput:
         GPIO.setup("P8_10", GPIO.IN)
         with pytest.raises(RuntimeError):
             GPIO.output("P8_10", GPIO.LOW)
-            GPIO.cleanup()
\ No newline at end of file
+            GPIO.cleanup()
